==> argrelay-0.5.1.dev5.tar.gz: argrelay-0.5.1.dev5/docs/test_data/TD_63_37_05_36.demo_services_data.md <==
---
test_data: TD_63_37_05_36
test_title: demo service data
---

This data is what `ServiceLoader` uses for `relay_demo` client from root `readme.md`:

| `CodeMaturity` | `GeoRegion` | `FlowStage`  | `ClusterName`          | `DataCenter` | `HostName`   | `ServiceName` | `IpAddress`      | `GroupLabel`         | is_populated     | comment                           |
|----------------|-------------|--------------|------------------------|--------------|--------------|---------------|------------------|----------------------|------------------|-----------------------------------|
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `dev` is everywhere but limited   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_a`         | `ip.192.168.1.1` | `aaa,sss`            | Y                |                                   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_b`         | `ip.192.168.1.1` | `bbb,sss`            | Y                |                                   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_c`         | `ip.192.168.1.1` | `ccc,sss`            | Y                |                                   |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `dev`          | `apac`      | `downstream` | `dev-apac-downstream`  | `dc.11`      | `zxcv-dd`    | `tt`          | `ip.172.16.1.2`  | `rrr`                | Y                |                                   |
| `dev`          | `apac`      | `downstream` | `dev-apac-downstream`  | `dc.01`      | `poiu-dd`    | `xx`          | `ip.192.168.1.3` | `rrr,hhh`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `emea` has no `s_c`               |
| `dev`          | `emea`      | `upstream`   | `dev-emea-upstream`    | `dc.22`      | `asdf-du`    | `s_a`         | `ip.172.16.2.1`  | `aaa,sss`            | Y                |                                   |
| `dev`          | `emea`      | `upstream`   | `dev-emea-upstream`    | `dc.22`      | `asdf-du`    | `s_b`         | `ip.172.16.2.1`  | `bbb,sss`            | Y                |                                   |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `dev`          | `emea`      | `downstream` | `dev-emea-downstream`  | `dc.02`      | `xcvb-dd`    | `xx`          | `ip.192.168.2.2` | `rrr,hhh`            | Y                |                                   |
| `dev`          | `emea`      | `downstream` | `dev-emea-downstream`  | `dc.02`      | `xcvb-dd`    | `zz`          | `ip.192.168.2.2` | `rrr,hhh,odd`        | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `amer` has only `dev` `upstream`  |
| `dev`          | `amer`      | `upstream`   | `dev-amer-upstream`    | `dc.03`      | `qwer-du`    | `s_a`         | `ip.192.168.3.1` | `aaa,sss`            | Y                | `amer` has only `s_a` service     |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.04`      | `hjkl-qu`    | `s_a`         | `ip.192.168.4.1` | `aaa,sss`            | Y                |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.04`      | `hjkl-qu`    | `s_b`         | `ip.192.168.4.1` | `bbb,sss`            | Y                |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.44`      | `poiu-qu`    | `s_c`         | `ip.172.16.4.2`  | `ccc,sss`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `emea`      | `downstream` | `qa-emea-downstream`   | `dc.05`      |              |               |                  |                      | Y                | no `qa` in `emea` (empty cluster) |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `amer`      | `upstream`   | `qa-amer-upstream`     | `dc.06`      | `rtyu-qu`    | `s_a`         | `ip.192.168.6.1` | `aaa,sss`            | Y                |                                   |
| `qa`           | `amer`      | `upstream`   | `qa-amer-upstream`     | `dc.06`      | `rt-qu`      |               | `ip.192.168.6.2` |                      | Y                | host `rt-du` has no services      |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.06`      | `sdfgh-qd`   | `tt1`         | `ip.192.168.6.3` | `rrr`                | Y                |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.06`      | `sdfgb-qd`   | `xx`          | `ip.192.168.6.4` | `rrr,hhh`            | Y                |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.66`      | `sdfg-qd`    |               | `ip.172.16.6.5`  |                      | Y                | host `sdfg-qd` has no services    |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `prod` is only in `apac`          |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-1`  | `s_a`         | `ip.192.168.7.1` | `aaa,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-1`  | `s_b`         | `ip.192.168.7.1` | `bbb,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-3`  | `s_c`         | `ip.192.168.7.2` | `ccc,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_a`         | `ip.172.16.7.2`  | `aaa,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_b`         | `ip.172.16.7.2`  | `bbb,xxx`            | Y                | diff `GroupLabel` for `s_b`       |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_c`         | `ip.172.16.7.2`  | `ccc,sss`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-1`  | `tt1`         | `ip.192.168.7.3` | `rrr`                | Y                |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-2`  | `tt2`         | `ip.192.168.7.4` | `rrr`                | Y                |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-2`  | `xx`          | `ip.192.168.7.4` | `rrr,hhh`            | Y                |                                   |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | ------------------------------    |
|                |             |              |                        |              |              |               |                  |                      |                  |                                   |

There is no purpose to cover all special cases (other `test_data` is supposed to cover that) -
the intention is to provide enough data to play with (without overwhelming manual maintenance).

It permutes arg values for arg types defined in `ServiceArgType`:

*   `CodeMaturity`:

    *   `dev`
    *   `qa`
    *   `prod`

*   `GeoRegion`:

    *   `apac`
    *   `emea`
    *   `amer`

*   `FlowStage`:

    *   `upstream`
    *   `downstream`

*   `ClusterName`:

    These arg values are composite ids with `${CodeMaturity}-${GeoRegion}-${FlowStage}` format.

*   `HostName`:

    See table above.

    Each `HostName` has prefix - a random set of letters (used to demo completion by prefix).

    Each `HostName` contains suffix = the first letters of `${CodeMaturity}` and `${FlowStage}`, for example:

    ```
    dev downstream    ->   dd
    qa downstream     ->   qd
    prod upstream     ->   pu
    ```

*   `ServiceName`:

    All `ServiceName` are arbitrary and can be repeated across different `ClusterName`.

    See table above.

==> argrelay-0.6.8.dev0.tar.gz: argrelay-0.6.8.dev0/docs/test_data/TD_63_37_05_36.demo_services_data.md <==
---
test_data: TD_63_37_05_36
test_title: demo service data
---

This data is what `ServiceLoader` uses for `relay_demo` client from root `readme.md`:

| `code_maturity` | `geo_region` | `flow_stage`  | `cluster_name`          | `data_center` | `host_name`   | `service_name` | `ip_address`      | `group_label`         | is_populated     | comment                           |
|----------------|-------------|--------------|------------------------|--------------|--------------|---------------|------------------|----------------------|------------------|-----------------------------------|
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `dev` is everywhere but limited   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_a`         | `ip.192.168.1.1` | `aaa,sss`            | Y                |                                   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_b`         | `ip.192.168.1.1` | `bbb,sss`            | Y                |                                   |
| `dev`          | `apac`      | `upstream`   | `dev-apac-upstream`    | `dc.01`      | `zxcv-du`    | `s_c`         | `ip.192.168.1.1` | `ccc,sss`            | Y                |                                   |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `dev`          | `apac`      | `downstream` | `dev-apac-downstream`  | `dc.11`      | `zxcv-dd`    | `tt`          | `ip.172.16.1.2`  | `rrr`                | Y                |                                   |
| `dev`          | `apac`      | `downstream` | `dev-apac-downstream`  | `dc.01`      | `poiu-dd`    | `xx`          | `ip.192.168.1.3` | `rrr,hhh`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `emea` has no `s_c`               |
| `dev`          | `emea`      | `upstream`   | `dev-emea-upstream`    | `dc.22`      | `asdf-du`    | `s_a`         | `ip.172.16.2.1`  | `aaa,sss`            | Y                |                                   |
| `dev`          | `emea`      | `upstream`   | `dev-emea-upstream`    | `dc.22`      | `asdf-du`    | `s_b`         | `ip.172.16.2.1`  | `bbb,sss`            | Y                |                                   |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `dev`          | `emea`      | `downstream` | `dev-emea-downstream`  | `dc.02`      | `xcvb-dd`    | `xx`          | `ip.192.168.2.2` | `rrr,hhh`            | Y                |                                   |
| `dev`          | `emea`      | `downstream` | `dev-emea-downstream`  | `dc.02`      | `xcvb-dd`    | `zz`          | `ip.192.168.2.2` | `rrr,hhh,odd`        | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `amer` has only `dev` `upstream`  |
| `dev`          | `amer`      | `upstream`   | `dev-amer-upstream`    | `dc.03`      | `qwer-du`    | `s_a`         | `ip.192.168.3.1` | `aaa,sss`            | Y                | `amer` has only `s_a` service     |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.04`      | `hjkl-qu`    | `s_a`         | `ip.192.168.4.1` | `aaa,sss`            | Y                |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.04`      | `hjkl-qu`    | `s_b`         | `ip.192.168.4.1` | `bbb,sss`            | Y                |                                   |
| `qa`           | `apac`      | `upstream`   | `qa-apac-upstream`     | `dc.44`      | `poiu-qu`    | `s_c`         | `ip.172.16.4.2`  | `ccc,sss`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `emea`      | `downstream` | `qa-emea-downstream`   | `dc.05`      |              |               |                  |                      | Y                | no `qa` in `emea` (empty cluster) |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `amer`      | `upstream`   | `qa-amer-upstream`     | `dc.06`      | `rtyu-qu`    | `s_a`         | `ip.192.168.6.1` | `aaa,sss`            | Y                |                                   |
| `qa`           | `amer`      | `upstream`   | `qa-amer-upstream`     | `dc.06`      | `rt-qu`      |               | `ip.192.168.6.2` |                      | Y                | host `rt-du` has no services      |
|                |             | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.06`      | `sdfgh-qd`   | `tt1`         | `ip.192.168.6.3` | `rrr`                | Y                |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.06`      | `sdfgb-qd`   | `xx`          | `ip.192.168.6.4` | `rrr,hhh`            | Y                |                                   |
| `qa`           | `amer`      | `downstream` | `qa-amer-downstream`   | `dc.66`      | `sdfg-qd`    |               | `ip.172.16.6.5`  |                      | Y                | host `sdfg-qd` has no services    |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | `prod` is only in `apac`          |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-1`  | `s_a`         | `ip.192.168.7.1` | `aaa,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-1`  | `s_b`         | `ip.192.168.7.1` | `bbb,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.07`      | `qwer-pd-3`  | `s_c`         | `ip.192.168.7.2` | `ccc,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_a`         | `ip.172.16.7.2`  | `aaa,sss`            | Y                |                                   |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_b`         | `ip.172.16.7.2`  | `bbb,xxx`            | Y                | diff `group_label` for `s_b`       |
| `prod`         | `apac`      | `upstream`   | `prod-apac-upstream`   | `dc.77`      | `qwer-pd-2`  | `s_c`         | `ip.172.16.7.2`  | `ccc,sss`            | Y                |                                   |
|                | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-1`  | `tt1`         | `ip.192.168.7.3` | `rrr`                | Y                |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-2`  | `tt2`         | `ip.192.168.7.4` | `rrr`                | Y                |                                   |
| `prod`         | `apac`      | `downstream` | `prod-apac-downstream` | `dc.07`      | `wert-pd-2`  | `xx`          | `ip.192.168.7.4` | `rrr,hhh`            | Y                |                                   |
| -------------- | ----------- | ------------ | ---------------------- | ------------ | ------------ | ------------- | ---------------- | -------------------- | ---------------- | ------------------------------    |
|                |             |              |                        |              |              |               |                  |                      |                  |                                   |

There is no purpose to cover all special cases (other `test_data` is supposed to cover that) -
the intention is to provide enough data to play with (without overwhelming manual maintenance).

It permutes arg values for arg types defined in `ServiceArgType`:

*   `code_maturity`:

    *   `dev`
    *   `qa`
    *   `prod`

*   `geo_region`:

    *   `apac`
    *   `emea`
    *   `amer`

*   `flow_stage`:

    *   `upstream`
    *   `downstream`

*   `cluster_name`:

    These arg values are composite ids with `${code_maturity}-${geo_region}-${flow_stage}` format.

*   `host_name`:

    See table above.

    Each `host_name` has prefix - a random set of letters (used to demo completion by prefix).

    Each `host_name` contains suffix = the first letters of `${code_maturity}` and `${flow_stage}`, for example:

    ```
    dev downstream    ->   dd
    qa downstream     ->   qd
    prod upstream     ->   pu
    ```

*   `service_name`:

    All `service_name` are arbitrary and can be repeated across different `cluster_name`.

    See table above.
